api.datastores.v1.store.store — Argus-Toolbelt 1.0 documentation

# Source code for api.datastores.v1.store.store

    """Autogenerated API"""
    import requests
    from argus_cli.plugin import register_command

    @register_command(extending=('datastores','v1','store',''))
    def get_entries_from_store_simplified(dataStore: str, customerID: list = None, key: list = None, offset: int = 0, limit: int = 25, includeDeleted: bool = 'True',json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Returns datastore entries for the specified store, matching query parameters. (PUBLIC)

        :param str dataStore: Store name
        :param list customerID: Limit search to entries for the specified customers
        :param list key: Limit search to the specified entry keys
        :param int offset: Skip a number of results
        :param int limit: Maximum number of returned results
        :param bool includeDeleted: Include deleted/expired keys
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises StoreNotFoundException: on 404
        :returns: {"offset": 716, "limit": 60, "responseCode": 200, "count": 177, "data": [{"dataStoreName": "Republican society site no recent receive military.", "lastUpdatedTimestamp": 480243691, "lastUpdatedByUser": {"id": 768, "customerID": 397, "userName": "rogermoreno", "name": "Matthew Harris"}, "key": "He operation customer state.", "value": "Risk it animal chance base somebody not.", "flags": ["DELETED"]}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Mean relationship during nature.", "messageTemplate": "Officer race glass special.", "field": "Civil hair necessary other move goal produce number.", "parameter": {}, "timestamp": 1085597225}], "currentPage": 853, "size": 961}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/datastores/v1/store/{dataStore}".format(dataStore=dataStore)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if offset:
            body.update({"offset": offset})

        if limit:
            body.update({"limit": limit})

        if includeDeleted:
            body.update({"includeDeleted": includeDeleted})

        if customerID:
            body.update({"customerID": customerID})

        if key:
            body.update({"key": key})

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('datastores','v1','store',''))
    def put_data_store_entries(dataStore: str, customerID: int = None, entries: list = None,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Updates the provided datastore entries for the specified store. (PUBLIC)

        :param str dataStore: Store name
        :param int customerID: ID of customer to bind data to. If not set, default is to bind to the current users customer (or none, if datastore is global)
        :param list entries: Entries to add
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises StoreNotFoundException: on 404
        :returns: {"offset": 324, "limit": 195, "responseCode": 200, "count": 101, "data": [{"dataStoreName": "Cell feeling street step.", "lastUpdatedTimestamp": 533776117, "lastUpdatedByUser": {"id": 338, "customerID": 111, "userName": "cvaldez", "name": "Jesse Smith"}, "key": "Concern sit newspaper quickly impact cause any heart.", "value": "Hundred red road call mind ok political view.", "flags": ["DELETED"]}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Hit far animal across.", "messageTemplate": "Computer very difficult everybody full.", "field": "Today picture recent both there agency.", "parameter": {}, "timestamp": 901042070}], "currentPage": 883, "size": 632}
        """
        from requests import put
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/datastores/v1/store/{dataStore}".format(dataStore=dataStore)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if customerID:
            body.update({"customerID": customerID})

        if entries:
            body.update({"entries": entries})

        response = put(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('datastores','v1','store',''))
    def delete_data_store_entries(dataStore: str, key: list = None, customerID: int = None,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Deletes the specified datastore entries for the specified store. (PUBLIC)

        :param str dataStore: Store name
        :param list key: Datastore keys to delete
        :param int customerID: Specify datastore to delete entries from (default is users customer)
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises StoreNotFoundException: on 404
        :returns: {"offset": 973, "limit": 116, "responseCode": 200, "count": 181, "data": [{"dataStoreName": "Require discuss outside family first.", "lastUpdatedTimestamp": 149334997, "lastUpdatedByUser": {"id": 573, "customerID": 699, "userName": "stevenjones", "name": "Sarah Lee"}, "key": "Bed late study responsibility last wish box.", "value": "Although above marriage.", "flags": ["DELETED"]}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Audience attention compare college respond tell.", "messageTemplate": "Next event young pull system threat run.", "field": "Say discussion everybody deep.", "parameter": {}, "timestamp": 907234967}], "currentPage": 395, "size": 215}
        """
        from requests import delete
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/datastores/v1/store/{dataStore}".format(dataStore=dataStore)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if key:
            body.update({"key": key})

        if customerID:
            body.update({"customerID": customerID})

        response = delete(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('datastores','v1','store',''))
    def get_entries_from_store(dataStore: str, limit: int = None, offset: int = None, subCriteria: list = None, customerID: list = None, userID: list = None, key: list = None, fromKey: str = None, toKey: str = None, startTimestamp: int = None, endTimestamp: int = None, sortBy: list = None, includeFlags: list = None, excludeFlags: list = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False',json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Returns datastore entries for the specified store, matching the search criteria. (PUBLIC)

        :param str dataStore: Store name
        :param int limit: Set this value to set max number of results. By default, no restriction on result set size.
        :param int offset: Set this value to skip the first (offset) objects. By default, return result from first object.
        :param list subCriteria:
        :param list customerID: Restrict search to data belonging to specified customers.
        :param list userID: Restrict search to entries which was last updated by specified users.
        :param list key: Restrict search to the specified key (entries).
        :param str fromKey: Restrict search to entries (map keys) which are greater than this key (including, by lexical order).
        :param str toKey: Restrict search to entries (map keys) which are less than this key (including, by lexical order).
        :param int startTimestamp: Restrict search to entries which are last updated after this timestamp (including).
        :param int endTimestamp: Restrict search to entries which are last updated before this timestamp (including).
        :param list sortBy: List of properties to sort by (prefix with "-" to sort descending).
        :param list includeFlags: Only include objects which have includeFlags set.
        :param list excludeFlags: Exclude objects which have excludeFlags set.
        :param bool includeDeleted: Set to true to include deleted objects. By default, exclude deleted objects.
        :param bool exclude: Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded.
        :param bool required: Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria).
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises StoreNotFoundException: on 404
        :returns: {"offset": 387, "limit": 61, "responseCode": 200, "count": 628, "data": [{"dataStoreName": "Anyone would approach money.", "lastUpdatedTimestamp": 1241441595, "lastUpdatedByUser": {"id": 579, "customerID": 71, "userName": "richard25", "name": "Karina Avery"}, "key": "Mother apply local whether network.", "value": "Finish nice billion large plant.", "flags": ["DELETED"]}], "metaData": {"additionalProperties": {}}, "messages": [{"message": "Staff grow purpose name even.", "messageTemplate": "Morning small help require hit.", "field": "Effort fear include machine risk represent outside.", "parameter": {}, "timestamp": 574014704}], "currentPage": 348, "size": 617}
        """
        from requests import post
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/datastores/v1/store/{dataStore}/search".format(dataStore=dataStore)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if limit:
            body.update({"limit": limit})

        if offset:
            body.update({"offset": offset})

        if includeDeleted:
            body.update({"includeDeleted": includeDeleted})

        if subCriteria:
            body.update({"subCriteria": subCriteria})

        if exclude:
            body.update({"exclude": exclude})

        if required:
            body.update({"required": required})

        if customerID:
            body.update({"customerID": customerID})

        if userID:
            body.update({"userID": userID})

        if key:
            body.update({"key": key})

        if fromKey:
            body.update({"fromKey": fromKey})

        if toKey:
            body.update({"toKey": toKey})

        if startTimestamp:
            body.update({"startTimestamp": startTimestamp})

        if endTimestamp:
            body.update({"endTimestamp": endTimestamp})

        if sortBy:
            body.update({"sortBy": sortBy})

        if includeFlags:
            body.update({"includeFlags": includeFlags})

        if excludeFlags:
            body.update({"excludeFlags": excludeFlags})

        response = post(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('datastores','v1','store',''))
    def get_single_entry(dataStore: str, key: str, customerID: int = None, includeDeleted: bool = 'True',json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Returns the specified datastore entry for the specified store, or null if it does not exist (PUBLIC)

        :param str dataStore: Store name
        :param str key: Key to search
        :param int customerID: Search specified customer store for this key (default is users customer)
        :param bool includeDeleted: Include deleted/expired key
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises StoreNotFoundException: on 404
        :returns: {"offset": 893, "limit": 196, "responseCode": 200, "count": 764, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Field fear both woman away.", "messageTemplate": "Similar Mr green class sell.", "field": "Front sign drive me floor baby thing.", "parameter": {}, "timestamp": 376632086}], "currentPage": 960, "size": 257}
        """
        from requests import get
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/datastores/v1/store/{dataStore}/{key}".format(dataStore=dataStore, key=key)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if includeDeleted:
            body.update({"includeDeleted": includeDeleted})

        if customerID:
            body.update({"customerID": customerID})

        response = get(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response

    @register_command(extending=('datastores','v1','store',''))
    def put_single_data_store_entry(dataStore: str, key: str, customerID: int = None,json: bool = True, verify: bool = True, apiKey: str = "", authentication: dict = {}) -> dict:
        """Adds the provided datastore entry for the specified store. To use for lists (key, no value) (PUBLIC)

        :param str dataStore: Store name
        :param str key: Datastore key to set
        :param int customerID: Specify datastore to put entry to (default is users customer)
        :raises AuthenticationFailedException: on 401
        :raises ValidationErrorException: on 412
        :raises AccessDeniedException: on 403
        :raises StoreNotFoundException: on 404
        :returns: {"offset": 734, "limit": 403, "responseCode": 200, "count": 785, "metaData": {"additionalProperties": {}}, "messages": [{"message": "Follow light goal claim relate face other staff.", "messageTemplate": "Bank safe treat whether from sell.", "field": "Whose hard throughout beat war offer no rate.", "parameter": {}, "timestamp": 509730153}], "currentPage": 568, "size": 89}
        """
        from requests import put
        from argus_api.exceptions import http

        url = "https://portal.mnemonic.no/web/api/datastores/v1/store/{dataStore}/{key}".format(dataStore=dataStore, key=key)
        headers = {
            'Content-Type': 'application/json',
            'User-Agent': 'ArgusToolbelt/1.0'
        }

        if apiKey:
            headers["Argus-API-Key"] = apiKey
        elif authentication and isinstance(authentication, dict):
            headers.update(authentication)
        elif callable(authentication):
            headers.update(authentication(url))

        body = {}

        if customerID:
            body.update({"customerID": customerID})

        response = put(url, json=body if body else None, verify=verify, headers=headers)

        errors = []
        if response.status_code == 401:
            raise http.AuthenticationFailedException(response)
        elif response.status_code == 403:
            raise http.AccessDeniedException(response)
        elif response.status_code == 412:
            raise http.ValidationErrorException(response)
        elif response.status_code == 404:
            raise http.ObjectNotFoundException(response)

        return response.json() if json else response